#!/usr/bin/env python2

"""
    This is "Super Moon Adventure Turbo Extreme" a silly game made for 
    pyweek #17 Copyright (C) 2013 Paul Brownsea

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import pygame, sys, random
from pygame.locals import *

SCREENWIDTH = 1024
SCREENHEIGHT = 768
pygame.init()
#SCREEN = pygame.display.set_mode((SCREENWIDTH, SCREENHEIGHT), pygame.FULLSCREEN)
SCREEN = pygame.display.set_mode((SCREENWIDTH, SCREENHEIGHT), 0)
FONT = pygame.font.Font('freesansbold.ttf', 16)
FONT1 = pygame.font.Font('freesansbold.ttf', 32)
FPSCLOCK = pygame.time.Clock()
FPS = 24
BLACK = (0, 0, 0)
WHITE = (255, 255, 255)
YELLOW = (255, 255, 0)
RED = (255, 0, 0)
GREEN = (0, 255, 0)
GREY = (80, 80, 80)
class Gamer (object):
	def __init__ (self):
		self.lives = 5

def doText (position, fgColour, bgColour, text, size):
	if size == 16:
		font = FONT
	elif size == 32:
		font = FONT1
	else:
		print "Unknown font size :("
		sys.exit()
	txtsurf = font.render(text, True, fgColour, bgColour)
	txtrect = txtsurf.get_rect()
	if position [0] != None:
		txtrect.topleft = ((position [0], position [1]))
	else:
		txtrect.midtop = ((SCREENWIDTH / 2 ,position [1]))
	txt = SCREEN.blit(txtsurf, txtrect)
	return txt

def titleScreen ():
	done = False
	redo = True
	updates = []
	while not done:
		if redo:
			SCREEN.blit (pygame.image.load('background_title.png').convert(), (0, 0))
			pygame.display.update ()
			redo = False

		startButton = doText ((None, 100), BLACK, WHITE, "Start", 32)
		updates.append (startButton)
		infoButton = doText ((None, 150), BLACK, WHITE, "Info", 32)
		updates.append (infoButton)
		quitButton = doText ((None, 200), BLACK, WHITE, "Quit", 32)
		updates.append (quitButton)

		cheatButton = doText ((10, 705), BLACK, WHITE, "Just so you can try out each level for pyweek:", 16)
		updates.append (cheatButton)
		cheat1Button = doText ((50, 720), BLACK, WHITE, "Level 1", 16)
		updates.append (cheat1Button)
		cheat2Button = doText ((50, 735), BLACK, WHITE, "Level 2", 16)
		updates.append (cheat2Button)
		cheat3Button = doText ((50, 750), BLACK, WHITE, "Level 3", 16)
		updates.append (cheat3Button)

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
			elif event.type == MOUSEBUTTONDOWN:
				if startButton.collidepoint (event.pos):
					doGame ()
					redo = True
				elif infoButton.collidepoint (event.pos):
					staticScreen ('info')
					redo = True
				elif cheat1Button.collidepoint (event.pos):
					staticScreen ('inst1')
					gamer = Gamer ()
					game1 (gamer)
					redo = True
				elif cheat2Button.collidepoint (event.pos):
					staticScreen ('inst2')
					gamer = Gamer ()
					game2 (gamer)
					redo = True
				elif cheat3Button.collidepoint (event.pos):
					staticScreen ('inst3')
					gamer = Gamer ()
					game3 (gamer)
					redo = True
				elif quitButton.collidepoint (event.pos):
					done = True
            			
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)

def staticScreen (screen):
	done = False
	updates = []
	SCREEN.blit (pygame.image.load('background_' + screen + '.png').convert(), (0, 0))
	pygame.display.update ()
	while not done:
		okButton = doText ((None, 700), BLACK, WHITE, "OK", 32)
		updates.append (okButton)

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
			elif event.type == MOUSEBUTTONDOWN:
				if okButton.collidepoint (event.pos):
					done = True

		keys = pygame.key.get_pressed()  #checking pressed keys
		if keys[pygame.K_RETURN]:
			done = True
			            			
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)

class Pad (pygame.sprite.DirtySprite):
	def __init__(self, x, y, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y

class Star (pygame.sprite.DirtySprite):
	def __init__(self, x, y, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.image.set_colorkey(BLACK)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y
	        
	def update (self):
		if random.randrange (10000) >= 9999:
			for g in self.groups:
				self.remove (g)
				
class Lander (pygame.sprite.DirtySprite):
	def __init__(self, x, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.image.set_colorkey(WHITE)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = 0
		self.fuel = 100 
		self.thrust_left = False
		self.thrust_right = False
		self.thrust_up = False
		self.down = 0.0
		self.left = 0
		self.right = 0
	        
	def update (self):
		# Should check if we are too far left or right...
		useFuel = 0.75
		if self.fuel > 0:
			if self.thrust_left:
				self.fuel = self.fuel - useFuel
				self.left = self.left + useFuel
			if self.thrust_right:
				self.fuel = self.fuel - useFuel
				self.right = self.right + useFuel
			if self.thrust_up:
				self.fuel = self.fuel - useFuel
				self.down = self.down - 0.5
				# should check if we've flown off into space...
		else:
			self.thrust_left = False
			self.thrust_right = False
			self.thrust_up = False
			
		if not self.thrust_up:
			self.down = self.down + 0.5
			
		horizontal = self.left - self.right
		self.rect.left = self.rect.left + horizontal
		
		vertical = self.down
		self.rect.top = self.rect.top + vertical
            
def game1 (gamer):
	redo = True
	updates = []
	lander_img = pygame.image.load('lander.png').convert()
	pad_img = pygame.image.load('pad.png').convert()
	star_img = pygame.image.load('star.png').convert()
	done = False	
	maxspeed = 7
	
	while not done:
		if redo == True:
			background_img = pygame.image.load('background_game1.png').convert()
			SCREEN.blit (background_img, (0, 0))
			pygame.display.update ()
			star_sprites = pygame.sprite.RenderUpdates ()
			player_sprites = pygame.sprite.RenderUpdates ()
			all_sprites = pygame.sprite.RenderUpdates ()
			
			updates.append (pygame.draw.rect (SCREEN, GREY, Rect (0, 700, SCREENWIDTH, SCREENHEIGHT)))
			
			player = Lander (random.randrange(SCREENWIDTH), lander_img, [player_sprites, all_sprites])
			player_sprites.add (player)		
			all_sprites.add (player)		
			
			pad = Pad (320, 700, pad_img, [all_sprites])
			all_sprites.add (pad)			
			redo = False
			
			go = False
		
		while len (star_sprites) < 50:
			star = Star (random.randrange(SCREENWIDTH), random.randrange(SCREENHEIGHT - 78), star_img, [star_sprites, all_sprites])
			star_sprites.add (star)
			all_sprites.add (star)		
		
		if player.rect.bottom >= pad.rect.top:
			if player.rect.left >= pad.rect.left - 20 and player.rect.right <= pad.rect.right + 20:
					if player.down > maxspeed:
						gamer.lives = gamer.lives - 1
						staticScreen ('died')
						redo = True
					else:
						done = True
			else:
				gamer.lives = gamer.lives - 1
				staticScreen ('died')
				redo = True
			
		if gamer.lives <= 0:
			done = True

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
		keys = pygame.key.get_pressed()  #checking pressed keys
		if keys[pygame.K_RIGHT]:
			player.thrust_left = True
		else:
			player.thrust_left = False
		if keys[pygame.K_LEFT]:
			player.thrust_right = True
		else:
			player.thrust_right = False
		if keys[pygame.K_UP]:
			player.thrust_up = True
		else:
			player.thrust_up = False
		if keys[pygame.K_DOWN]:
			go = True

		all_sprites.clear (SCREEN, background_img)

		star_sprites.update ()
		
		if go:
			player_sprites.update ()

		updates.extend (all_sprites.draw (SCREEN))
		
		updates.append (pygame.draw.rect (SCREEN, BLACK, Rect (0, 0, SCREENWIDTH, 15)))
		doText ((0, 0), WHITE, BLACK, "Fuel " + str (player.fuel) + "%", 16)
		if player.down < maxspeed * 0.7:
			c = GREEN
		elif player.down > maxspeed:
			c = RED
		else:
			c = YELLOW
		doText ((90, 0), WHITE, BLACK, "Lives " + str (gamer.lives), 16)
		doText ((270, 0), c, BLACK, "Speed " + str (player.down), 16)
		#updates.append (doText ((None, 20), WHITE, BLACK, "Land your lunar module using the arrow keys. Don't run out of fuel, don't hit the ground too fast. Tap down when you are ready.", 16))
			
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)
	return gamer

class Miner (pygame.sprite.DirtySprite):
	def __init__(self, x, y, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.imgs = {
			'n': pygame.image.load('minern.png').convert(),
			'e': pygame.image.load('minere.png').convert(),
			's': pygame.image.load('miners.png').convert(),
			'w': pygame.image.load('minerw.png').convert()
		}
		self.pointing = 'e'
		self.image = self.imgs ['e']
		self.groups = groups
		self.image.set_colorkey(WHITE)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y
		self.direction = 'stop'
		self.speed = 10
		self.weapon = pygame.time.get_ticks()
		self.helium = 0
		
	def update (self, heliums, weapons):
		if self.direction == 'up':
			self.rect.y = self.rect.y - self.speed
			self.pointing = 'n'
		elif self.direction == 'down':
			self.rect.y = self.rect.y + self.speed
			self.pointing = 's'
		elif self.direction == 'left':
			self.rect.x = self.rect.x - self.speed
			self.pointing = 'w'
		elif self.direction == 'right':
			self.rect.x = self.rect.x + self.speed
			self.pointing = 'e'
		self.image = self.imgs [self.pointing]
		self.image.set_colorkey(WHITE)
		
class Rock (pygame.sprite.DirtySprite):
	def __init__(self, x, y, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.image.set_colorkey(WHITE)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y

class BadMiner (pygame.sprite.DirtySprite):
	def __init__(self, x, y, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.image.set_colorkey(WHITE)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y
		self.direction = 'stop'
		self.speed = 10
	def update (self, rocks):
		ox = self.rect.x
		oy = self.rect.y
		if self.direction == 'up':
			self.rect.y = self.rect.y - self.speed
		elif self.direction == 'down':
			self.rect.y = self.rect.y + self.speed
		elif self.direction == 'left':
			self.rect.x = self.rect.x - self.speed
		elif self.direction == 'right':
			self.rect.x = self.rect.x + self.speed
		else:
			newdir = random.randrange (4)
			if newdir == 0:
				self.direction = 'up'
			elif newdir == 1:
				self.direction = 'down'
			elif newdir == 2:
				self.direction = 'left'
			elif newdir == 3:
				self.direction = 'right'
		stop = False

		for rock in rocks:
			if self.rect.colliderect (rock.rect):
				stop = True
				break
		if self.rect.left < 0:
			stop = True
		elif self.rect.top < 0:
			stop = True
		elif self.rect.right > SCREENWIDTH:
			stop = True
		elif self.rect.bottom > SCREENHEIGHT:
			stop = True
		
		if stop:
			self.rect.x = ox
			self.rect.y = oy
			self.direction = 'stop'

class Helium (pygame.sprite.DirtySprite):
	def __init__(self, x, y, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.image.set_colorkey(WHITE)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y

class Weapon (pygame.sprite.DirtySprite):
	def __init__(self, x, y, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.image.set_colorkey(WHITE)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y

def game2 (gamer):
	redo = True
	rock_img = pygame.image.load('rock.png').convert()
	badminer_img = pygame.image.load('badminer.png').convert()
	helium_img = pygame.image.load('helium.png').convert()
	weapon_img = pygame.image.load('weapon.png').convert()
	background_img = pygame.image.load('background_game2.png').convert()

	baddie_sprites = pygame.sprite.RenderUpdates ()
	player_sprites = pygame.sprite.RenderUpdates ()
	rock_sprites = pygame.sprite.RenderUpdates ()
	helium_sprites = pygame.sprite.RenderUpdates ()
	weapon_sprites = pygame.sprite.RenderUpdates ()
	all_sprites = pygame.sprite.RenderUpdates ()
	
	for x in xrange (SCREENWIDTH/25):
		for y in xrange (SCREENHEIGHT/25):
			rock = Rock (x * 25, y * 25, rock_img, [all_sprites, rock_sprites])
			rock_sprites.add (rock)
			all_sprites.add (rock)
	
	done = False
	first = True
	while not done:
		if redo == True:
			SCREEN.blit (background_img, (0, 0))
			pygame.display.update ()
			redo = False
			updates = []
			try:
				got = player.helium
			except NameError:
				got = 0
			player = Miner (0, 100, [all_sprites, player_sprites])
			player.helium = got
			player_sprites.add (player)		
			all_sprites.add (player)		
			
		while len (weapon_sprites) < 2:
			weapon = Weapon (random.randrange(SCREENWIDTH/25) * 25, random.randrange(SCREENHEIGHT/25) * 25, weapon_img, [all_sprites, baddie_sprites])
			weapon_sprites.add (weapon)
			all_sprites.add (weapon)
			pygame.sprite.groupcollide (weapon_sprites, rock_sprites, False, True)
			if not first:
				player.weapon = random.randrange(pygame.time.get_ticks() + 2000, pygame.time.get_ticks() + 12000)

		while len (baddie_sprites) < 12:
			baddie = BadMiner (random.randrange(SCREENWIDTH/25) * 25, random.randrange(SCREENHEIGHT/25) * 25, badminer_img, [all_sprites, baddie_sprites])
			baddie_sprites.add (baddie)
			all_sprites.add (baddie)
			pygame.sprite.groupcollide (baddie_sprites, rock_sprites, False, True)
			if not first:
				helium = Helium (random.randrange(SCREENWIDTH/25) * 25, random.randrange(SCREENHEIGHT/25) * 25, helium_img, [all_sprites, helium_sprites])
				helium_sprites.add (helium)
				all_sprites.add (helium)
				pygame.sprite.groupcollide (helium_sprites, rock_sprites, False, True)
				
		first = False
			
		baddie_sprites.update (rock_sprites)
		
		if len (player_sprites) == 0:
			redo = True
			gamer.lives = gamer.lives - 1
			if gamer.lives > 0:
				staticScreen ('died')
			
		if gamer.lives == 0:
			done = True
		if player.helium >= 10:
			done = True
		
		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()	

		keys = pygame.key.get_pressed()  #checking pressed keys
		player.direction = 'stop'
		if keys[pygame.K_LEFT]:
			player.direction = 'left'
		if keys[pygame.K_RIGHT]:
			player.direction = 'right'
		if keys[pygame.K_UP]:
			player.direction = 'up'
		if keys[pygame.K_DOWN]:
			player.direction = 'down'
			
		player_sprites.update(helium_sprites, weapon_sprites)
		pygame.sprite.groupcollide (player_sprites, rock_sprites, False, True)
		pygame.sprite.groupcollide (player_sprites, weapon_sprites, False, True)
		if pygame.sprite.spritecollideany(player, helium_sprites) is not None:
			player.helium = player.helium + 1
		pygame.sprite.groupcollide (player_sprites, helium_sprites, False, True)
		meDie = True
		theyDie = False
		if player.weapon > pygame.time.get_ticks():
			meDie = False
			theyDie = True
		pygame.sprite.groupcollide (player_sprites, baddie_sprites, meDie,theyDie)
				
		all_sprites.clear (SCREEN, background_img)
		updates.extend (all_sprites.draw (SCREEN))
		
		updates.append (pygame.draw.rect (SCREEN, BLACK, Rect (0, 0, SCREENWIDTH, 15)))
		doText ((0, 0), WHITE, BLACK, "Lives " + str (gamer.lives), 16)
		yn = 0
		if player.weapon > pygame.time.get_ticks():
			yn = round ((player.weapon - pygame.time.get_ticks())/1000)
		doText ((180, 0), WHITE, BLACK, "Weapon: " + str(yn), 16)
		doText ((300, 0), WHITE, BLACK, "Helium " + str (player.helium), 16)
		#updates.append (doText ((0, 20), WHITE, BLACK, "Collect weapon (green) kill (touch) enemy (red) then collect helium (yellow). 5 wins the level.", 16))
		
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)	
		#print round (FPSCLOCK.get_fps())
	return gamer

class Runner (pygame.sprite.DirtySprite):
	def __init__(self):
		pygame.sprite.Sprite.__init__(self)
		
		self.aniFrames = []
		self.aniFrames.append (pygame.image.load('runner1.png').convert())
		self.aniFrames.append (pygame.image.load('runner2.png').convert())
		self.aniFrames.append (pygame.image.load('runner3.png').convert())
		
		self.image = self.aniFrames [0]
		self.image.set_colorkey(BLACK)
		self.rect = self.image.get_rect()
		self.rect.x = 100
		self.rect.y = 400
		self.jump = False
		self.onGround = False
		self.jumping = False
		self.jumpTo = None
		self.aniState = 0
		
	def update (self):
		if self.onGround:
			self.aniState = self.aniState + 1
			if self.aniState >= 3:
				self.aniState = 0
			self.image = self.aniFrames [self.aniState]
			
		if self.jump:
			if self.onGround:
				self.jumping = True
				self.jumpTo = self.rect.bottom - 200
		self.jump = False
		if self.jumping:
			self.rect.bottom = self.rect.bottom - 10
			if self.rect.bottom <= self.jumpTo:
				self.jumping = False
		else:
			if self.onGround == False:
				self.rect.bottom = self.rect.bottom + 10

class Block (pygame.sprite.DirtySprite):
	def __init__(self, img):
		pygame.sprite.Sprite.__init__(self)
		self.image = img
		self.image.set_colorkey(WHITE)
		self.rect = self.image.get_rect()
		self.rect.x = 100
		self.rect.y = 600
	def update (self):
		self.rect.x = self.rect.x - 10
			
def game3 (gamer):
	background_img = pygame.image.load('background_game3.png').convert()
	block_img = pygame.image.load('block.png').convert()
	done = False
	redo = True

	player_sprites = pygame.sprite.RenderUpdates ()
	block_sprites = pygame.sprite.RenderUpdates ()
	all_sprites = pygame.sprite.RenderUpdates ()

	while not done:
		if redo:
			endAt = pygame.time.get_ticks() + 30000 # 30 seconds of gameplay...
			SCREEN.blit (background_img, (0, 0))
			pygame.display.update ()
			redo = False
			updates = []
			player = Runner ()
			player_sprites.add (player)		
			block_sprites.empty()
			all_sprites.empty()
			all_sprites.add (player)
			
			for y in xrange (0, 3):
				for x in xrange ((SCREENWIDTH / 50) + 1):
					rock = Block (block_img)
					rock.rect.x = x * 50
					rock.rect.y = 600 + y * 50
					block_sprites.add (rock)
					all_sprites.add (rock)
			
		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()		

		keys = pygame.key.get_pressed()  #checking pressed keys
		if keys[pygame.K_RETURN]:
			player.jump = True
		elif keys[pygame.K_SPACE]:
			for rock in block_sprites:
				print rock.rect
			
		all_sprites.clear (SCREEN, background_img)

		block_sprites.update()
		
		player.onGround = False
		for rock in block_sprites:
			if rock.rect.top == player.rect.bottom:
				if (player.rect.right >= rock.rect.left and player.rect.right <= rock.rect.right) or (player.rect.left >= rock.rect.left and player.rect.left <= rock.rect.right):
					player.onGround = True
			if rock.rect.right <= 0:
				y = rock.rect.y
				rock.kill()
				if random.randrange (100) < 90:
					rock = Block (block_img)
					rock.rect.x = 1000
					rock.rect.y = y
					block_sprites.add (rock)
					all_sprites.add (rock)
		
		player_sprites.update()
		
		pygame.sprite.groupcollide (player_sprites, block_sprites, True, False)
		if len (player_sprites) == 0:
			gamer.lives = gamer.lives - 1
			redo = True
			if gamer.lives > 0:
				staticScreen ('died')
			
		if gamer.lives <= 0:
			done = True

		updates.extend (all_sprites.draw (SCREEN))
		
		updates.append (pygame.draw.rect (SCREEN, BLACK, Rect (0, 0, SCREENWIDTH, 15)))
		doText ((0, 0), WHITE, BLACK, "Lives " + str (gamer.lives), 16)
		doText ((200, 0), WHITE, BLACK, "Distance " + str (round((endAt - pygame.time.get_ticks())/1000, 0)), 16)
		#updates.append (doText ((0, 20), WHITE, BLACK, "Jump over objects.", 16))

		pygame.display.update (updates)
		updates = []
		
		if pygame.time.get_ticks() >= endAt:
			done = True
		
		FPSCLOCK.tick (FPS)
	return gamer

def doGame ():
	gamer = Gamer ()
	if gamer.lives > 0:
		staticScreen ('inst1')
		gamer = game1 (gamer)
	if gamer.lives > 0:
		staticScreen ('inst2')
		gamer = game2 (gamer)
	if gamer.lives > 0:
		staticScreen ('inst3')
		gamer = game3 (gamer)
		
	if gamer.lives > 0:
		staticScreen ('won')
	else:
		staticScreen ('lost')

titleScreen ()

pygame.quit()
sys.exit()

"""
Day 1:
Exciting - game theme chosen! Let's get started!
I decided to do a series of 'mini games' so I can complete each one and make as many more as time permits
Made an empty 'skeleton' game with placeholders for title screen, info screen, winning screen, losing screen, a death screen
Level 1 - land a lunar module on the moon
Spent longer on the random stars than I should have... especially as according to the NASA photos you can't see stars on the moon...
Todo:
Make proper backgrounds
Maybe sounds for button presses in menus
Make background stars varying sizes or at least smaller!

Day 2:
Got a mostly working first level for the game, trying to think of what to do with level 2
Came up with an idea for level 2... started it :) it's some sort of cross between dig dug and pacman
It's progressing nicely, but having a bit of a problem with fps due to excessive sprites
Todo:
Scoring in level one is wrong :p
Thinking I should *actually* draw some moon for the landing pad to sit on...
Make proper backgrounds
Make proper graphics
Sounds for in game events (but it's in space - you can't actually hear explosions!)
Maybe sounds for button presses in menus
Make background stars varying sizes or at least smaller!

Day 3:
Missed most of day 3 :(

Day 4:
Got level 2 into a working state... I think there is time for a level 3
Speeded (sped?) up player and baddies in level 2 and made the landing pad bigger in level 1
Made an 'instruction' or 'intro' screen for each level for a bit of storyline and instructions
Decided on what level 3 will be like. It's going to be one of those running games...
Todo:
Scoring in level one is wrong :p
Thinking I should *actually* draw some moon for the landing pad to sit on...
Make proper backgrounds
Make proper graphics
Sounds for in game events (but it's in space - you can't actually hear explosions!)
Maybe sounds for button presses in menus
Make background stars varying sizes or at least smaller!
Level 2 doesn't have any scoring...
Graphics, backgrounds, sounds and sprites :p
Level 2 has terrible framerate at times :/
Level 2 player sometimes spawns on enemy - equally enemy may spwn on player, weapon or helium  may spawn on anything...
Level 1 is still sodding hard - should make landing pad bigger!
Should make a countdown for weapon in level 2

Day 5:
Missed day 5 :(

Day 6:
Yes, my little running astronaut works OKish
Tidied up the menu and text a bit
Sorted out the background images
Todo:
Scoring in level one is wrong :p
Thinking I should *actually* draw some moon for the landing pad to sit on...
Make proper backgrounds
Make proper graphics
Sounds for in game events (but it's in space - you can't actually hear explosions!)
Maybe sounds for button presses in menus
Make background stars varying sizes or at least smaller!
Level 2 doesn't have any scoring...
Graphics, backgrounds, sounds and sprites :p
Level 2 has terrible framerate at times :/
Level 2 player sometimes spawns on enemy - equally enemy may spwn on player, weapon or helium  may spawn on anything...
Level 1 is still sodding hard - should make landing pad bigger!
Should make the return button 'click' "oK" in menus
little man need animation
lunar module needs 'flames'
just realised - game never ends - level 3 never finishes

Day 7:
Level 3 now finishes at 30 seconds...
Removed scoring, you win or die
Finished the graphics as best I can ;)
Todo:
Sounds for in game events (but it's in space - you can't actually hear explosions!)
Maybe sounds for button presses in menus
Level 2 player sometimes spawns on enemy - equally enemy may spawn on player, weapon or helium  may spawn on anything...
lunar module needs 'flames'
"""

"""
What have I used:
Archlinux
Geany
Python 2
Pygame
Gimp
"""
